==> 808-GumpEditor_src_0.3.1.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by GumpEditor.rc
//
#define IDC_FREEZE                      3
#define IDC_ALL                         4
#define IDC_NONE                        5
#define IDC_INVERT                      6
#define IDC_UNFREEZE                    7
#define IDC_FIND                        8
#define IDD_ABOUTBOX                    100
#define IDP_OLE_INIT_FAILED             100
#define IDC_CHECKCURSOR                 101
#define IDC_RADIOCURSOR                 102
#define IDD_DIAGRAMPROPERTYPAGE         104
#define IDC_MULTILINEEDITCURSOR         107
#define IDD_PROPPAGE_LARGE              107
#define IDC_COMBOCURSOR                 109
#define IDC_GROUPCURSOR                 110
#define IDC_LABELCURSOR                 111
#define IDC_EDITCURSOR                  112
#define IDC_DATECURSOR                  113
#define ID_VIEW_ARRANGE                 127
#define IDR_MAINFRAME                   128
#define IDR_GumpEditorTYPE              129
#define ID_INDICATOR_POS                129
#define IDC_FPOINT                      130
#define IDR_DYNCONTROLBAR               130
#define IDD_DIALOG_SETTINGS             130
#define ID_INDICATOR_GUMPID             130
#define IDC_SPLITTER                    131
#define IDR_DYNCONTROLBAR1              131
#define IDD_DIALOG_BUTTON_PROPERTIES    131
#define IDC_PICTURECURSOR               132
#define IDD_DIALOG_EDIT_PROPERTIES      132
#define IDR_MAINFRAME1                  132
#define IDB_BITMAP1                     133
#define IDC_LISTCURSOR                  133
#define IDC_BUTTONCURSOR                134
#define IDD_CTRLTYPE_DIALOG             135
#define IDC_BKGROUNDCURSOR              136
#define IDD_CTRLTYPE_DIALOG2            137
#define IDD_CTRL_TYPE_DIALOG            137
#define IDR_GUMPLIST_MENU               142
#define IDR_MAINFRAME2                  143
#define IDD_HUE_DIALOG                  144
#define IDD_PICTURE_PAGE                337
#define IDD_PICTURE_DIALOG              337
#define IDD_BUTTON_PAGE                 338
#define IDD_BUTTON_DIALOG               338
#define IDD_STATIC_DIALOG               340
#define IDD_EDIT_DIALOG                 341
#define IDD_BORDER_DIALOG               342
#define IDD_CHECKBOX_DIALOG             343
#define IDD_RADIO_DIALOG                344
#define IDD_CTRL_LIST_DIALOG            345
#define IDD_GUMP_PAGE                   347
#define IDC_TABORDER                    1000
#define IDC_EDIT_WIDTH                  1000
#define IDC_EDIT_NAME                   1000
#define IDC_TEXT                        1001
#define IDC_EDIT_HEIGHT                 1001
#define IDC_ORDINAL                     1002
#define IDC_RADIO1                      1002
#define IDC_EDIT_GRID_WIDTH             1002
#define IDC_RADIOID                     1003
#define IDC_RADIO2                      1003
#define IDC_EDIT_GRID_HEIGHT            1003
#define IDC_RADIO3                      1004
#define IDC_EDIT_LEFT                   1004
#define IDC_EDIT_TOP                    1005
#define IDC_RADIO4                      1005
#define IDC_GUMP_ID                     1006
#define IDC_EDIT_RIGHT                  1006
#define IDC_RADIO5                      1006
#define IDC_GUMP_ID2                    1007
#define IDC_EDIT_BOTTOM                 1007
#define IDC_RADIO6                      1007
#define IDC_GUMP_ID3                    1008
#define IDC_EDIT_TITLE                  1008
#define IDC_BUTTON_APPLY                1009
#define IDC_SPIN1                       1010
#define IDC_SPIN2                       1011
#define IDC_COMBO1                      1011
#define IDC_SPIN3                       1012
#define IDC_BUTTON2                     1013
#define IDC_SPIN6                       1013
#define IDC_BUTTON3                     1014
#define IDC_XPOS                        1014
#define IDC_SPIN7                       1014
#define IDC_YPOS                        1015
#define IDC_SPIN4                       1015
#define IDC_SPIN9                       1015
#define IDC_WIDTH                       1016
#define IDC_YPOS2                       1016
#define IDC_YSPIN                       1016
#define IDC_SPIN10                      1016
#define IDC_HEIGHT                      1017
#define IDC_SPIN5                       1017
#define IDC_W                           1017
#define IDC_SPIN11                      1017
#define IDC_WIDTH2                      1018
#define IDC_HEIGHT2                     1019
#define IDC_COMBO2                      1019
#define IDC_EVENT_ONCLICK               1020
#define IDC_COLOR                       1020
#define IDC_EVENT_ONCLOSE               1021
#define IDC_FONT_COMBO                  1021
#define IDC_HUE                         1021
#define IDC_EVENT_ONMOUSEUP             1022
#define IDC_EVENT_ONMOUSEDOWN           1023
#define IDC_HUEID_EDIT                  1023
#define IDC_EVENT_ONKEYPRESSED          1024
#define IDC_RGB_EDIT                    1024
#define IDC_COLOR_STATIC                1025
#define IDC_GROUP                       1025
#define IDC_HSPIN                       1025
#define IDC_TEXT_STATIC                 1026
#define IDC_SPIN8                       1026
#define IDC_SPIN                        1026
#define IDC_PASSWORD_CHECK              1027
#define IDC_NAME                        1028
#define IDC_TYPE                        1029
#define IDC_CHECK3                      1030
#define IDC_CTRL_LIST                   1031
#define IDC_ALPHA                       1032
#define IDC_XSPIN                       1033
#define IDC_FADE_ALPHA                  1033
#define IDC_WSPIN                       1034
#define IDC_FADE_TIME                   1034
#define IDC_ALPHASPIN                   1035
#define IDC_H                           1036
#define IDC_ALPHASPIN2                  1036
#define IDC_GUMP_SPIN                   1037
#define IDC_ALPHASPIN3                  1037
#define IDC_SHAPE                       1038
#define IDC_SELECT                      1039
#define IDC_UNSELECT                    1040
#define IDC_CHECK1                      1057
#define IDC_CHECK2                      1058
#define IDC_VISIBLE                     1275
#define IDC_HIDE                        1275
#define IDC_UNHIDE                      1276
#define IDC_LISTBOXTEXT                 1336
#define IDC_LISTBOXINFO                 1360
#define IDC_TABORDERLABEL               1361
#define IDC_TABORDERLABEL2              1362
#define IDC_TABORDERLABEL3              1363
#define IDC_TABORDERLABEL4              1364
#define IDC_TABORDERLABEL5              1365
#define IDC_TABORDERLABEL6              1366
#define IDC_TABORDERLABEL7              1367
#define IDC_TABORDERLABEL8              1368
#define IDC_TABORDERLABEL9              1369
#define IDC_TABORDERLABEL10             1370
#define IDC_TABORDERLABEL11             1371
#define IDC_TABORDERLABEL12             1372
#define IDC_LISTITEMS                   1842
#define IDC_READONLY                    1963
#define ID_SCREEN_DESIGNER              32771
#define ID_DYNBUTTONRADIO               32772
#define IDC_PROPERTIES                  32772
#define ID_DYNBUTTONDATE                32773
#define ID_DYNBUTTONPICTURE             32774
#define IDC_SETTINGS                    32774
#define IDC_PROPERTIES2                 32774
#define ID_DYNBUTTONBUTTON              32775
#define ID_ADD_BUTTON                   32775
#define IDC_SETTINGS2                   32775
#define ID_DYNBUTTONLIST                32776
#define ID_ADD_EDIT                     32776
#define ID_ADD_STATIC                   32777
#define ID_ADD_BUTTON2                  32777
#define IDC_90PERC                      32778
#define ID_ADD_EDIT2                    32778
#define ID_DYNBUTTONEDIT                32779
#define ID_DYNBUTTONEDITMULTI           32780
#define IDC_70PERC                      32780
#define IDC_60PERC                      32781
#define ID_ADD_STATIC2                  32781
#define IDC_50PERC                      32782
#define IDC_90PERC2                     32782
#define IDC_25PERC                      32783
#define IDC_80PERS                      32783
#define IDC_100PERC                     32784
#define IDC_70PERC2                     32784
#define IDC_110PERC                     32785
#define IDC_60PERC2                     32785
#define IDC_120PERC                     32786
#define IDC_50PERC2                     32786
#define IDC_130PERC                     32787
#define IDC_25PERC2                     32787
#define IDC_140PERC                     32788
#define IDC_100PERC2                    32788
#define IDC_150PERC                     32789
#define IDC_110PERC2                    32789
#define IDC_200PERC                     32790
#define IDC_120PERC2                    32790
#define IDC_80PERC                      32791
#define IDC_130PERC2                    32791
#define IDC_SELECT_ALL                  32792
#define IDC_140PERC2                    32792
#define IDC_150PERC2                    32793
#define ID_ADD_CHECKBOX                 32794
#define IDC_200PERC2                    32794
#define ID_ADD_RADIOBUTTON              32795
#define IDC_SELECT_ALL2                 32795
#define ID_ADD_LISTBOX                  32796
#define ID_ADD_CHECKBOX2                32796
#define ID_ADD_RADIOBUTTON2             32797
#define ID_ADD_GROUPBOX                 32798
#define ID_ADD_LISTBOX2                 32798
#define ID_ZOOM_IN                      32799
#define ID_ADD_GROUPBOX2                32799
#define ID_ZOOM_OUT                     32800
#define ID_ZOOM_IN2                     32800
#define ID_ADD_COMBOBOX                 32801
#define ID_ZOOM_OUT2                    32801
#define ID_SNAP_TO_GRID                 32802
#define ID_ADD_COMBOBOX2                32802
#define ID_SNAP_TO_GRID2                32803
#define ID_SHOW_GRID                    32804
#define ID_SNAP_TO_MARGIN               32805
#define ID_MARGINS                      32806
#define ID_RESTRAIN                     32807
#define ID_LEFT_ALIGN                   32808
#define ID_RIGHT_ALIGN                  32809
#define ID_TOP_ALIGN                    32810
#define ID_BOTTOM_ALIGN                 32811
#define ID_MAKE_SAME_SIZE               32812
#define ID_UP                           32813
#define ID_DOWN                         32814
#define ID_FRONT                        32815
#define ID_BOTTOM                       32816
#define ID_EXPORT                       32817
#define ID_ADD_NONE                     32819
#define ID_BUTTON_MULTIDRAW             32821
#define ID_DYNBUTTONLABEL               32843
#define ID_DYNBUTTONCOMBO               32844
#define ID_DYNBUTTONCHECK               32846
#define ID_DYNBUTTONGROUP               40001
#define ID_DYNBUTTONLEFTALIGN           40003
#define ID_DYNBUTTONTOPALIGN            40005
#define ID_DYNBUTTONBOTTOMALIGN         40006
#define ID_DYNBUTTONMAKESAMEWIDTH       40010
#define ID_DYNBUTTONMAKESAMEHEIGHT      40011
#define ID_DYNBUTTONMAKESAMESIZE        40012
#define ID_DYNBUTTONRIGHTALIGN          40015
#define ID_DYNBUTTONTOGGLEGRID          40017
#define ID_POPUP_PROPERTIES             40018
#define ID_POPUP_BRINGTOTOP             40021
#define ID_POPUP_BRINGTOBOTTOM          40022
#define ID_POPUP_GUMPIDCOPYTOCLIPBOARD  40027
#define ID_POPUP_INSERTGUMP             40028
#define ID_POPUP_COPYGUMPID             40029
#define ID_VIEW_HUEPICKER               40030
#define ID_VIEW_CONTROLLIST             40031
#define ID_VIEW_VIEWXML                 40032
#define ID_BUTTON40034                  40034

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        147
#define _APS_NEXT_COMMAND_VALUE         40035
#define _APS_NEXT_CONTROL_VALUE         1042
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif

==> 808-GumpEditor_src_0.4.0_20051208.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by GumpEditor.rc
//
#define IDC_FREEZE                      3
#define IDC_ALL                         4
#define IDR_TEMP                        4
#define IDC_NONE                        5
#define IDC_INVERT                      6
#define IDC_UNFREEZE                    7
#define IDC_FIND                        8
#define IDC_RELOAD_TAG                  9
#define IDD_ABOUTBOX                    100
#define IDP_OLE_INIT_FAILED             100
#define IDC_CHECKCURSOR                 101
#define IDC_RADIOCURSOR                 102
#define IDC_MULTILINEEDITCURSOR         107
#define IDD_PROPPAGE_LARGE              107
#define IDC_COMBOCURSOR                 109
#define IDC_GROUPCURSOR                 110
#define IDC_LABELCURSOR                 111
#define IDC_EDITCURSOR                  112
#define IDC_DATECURSOR                  113
#define ID_VIEW_ARRANGE                 127
#define IDR_MAINFRAME                   128
#define IDR_GumpEditorTYPE              129
#define ID_INDICATOR_POS                129
#define IDR_CODETYPE                    129
#define IDC_FPOINT                      130
#define IDD_DIALOG_SETTINGS             130
#define ID_INDICATOR_GUMPID             130
#define IDC_SPLITTER                    131
#define IDC_PICTURECURSOR               132
#define IDR_MAINFRAME1                  132
#define IDB_BITMAP1                     133
#define IDC_LISTCURSOR                  133
#define IDD_GOTOLINE                    133
#define IDC_BUTTONCURSOR                134
#define IDD_FIND                        134
#define IDD_CTRLTYPE_DIALOG             135
#define IDD_REPLACE                     135
#define IDC_BKGROUNDCURSOR              136
#define IDD_SCINTILLADLG                136
#define IDD_CTRLTYPE_DIALOG2            137
#define IDD_CTRL_TYPE_DIALOG            137
#define IDR_GUMPLIST_MENU               142
#define IDD_HUE_DIALOG                  144
#define IDD_WORDLIST                    148
#define IDD_POS                         149
#define IDI_ICON1                       150
#define IDI_LOGO                        150
#define IDD_CONFIG_DIALOG               154
#define IDD_PICTURE_PAGE                337
#define IDD_PICTURE_DIALOG              337
#define IDD_BUTTON_PAGE                 338
#define IDD_BUTTON_DIALOG               338
#define IDD_STATIC_DIALOG               340
#define IDD_EDIT_DIALOG                 341
#define IDD_BORDER_DIALOG               342
#define IDD_CHECKBOX_DIALOG             343
#define IDD_RADIO_DIALOG                344
#define IDD_CTRL_LIST_DIALOG            345
#define IDD_GUMP_PAGE                   347
#define IDD_CSL_DIALOG                  348
#define IDD_SCROLLBAR_DIALOG            349
#define IDD_SLIDER_DIALOG               350
#define IDD_CUSTOM_DIALOG               351
#define IDC_TABORDER                    1000
#define IDC_EDIT_WIDTH                  1000
#define IDC_EDIT_NAME                   1000
#define IDC_TEXT                        1001
#define IDC_EDIT_HEIGHT                 1001
#define IDC_ORDINAL                     1002
#define IDC_RADIO1                      1002
#define IDC_EDIT_GRID_WIDTH             1002
#define IDC_WORDLISTNO                  1002
#define IDC_FORWARD                     1002
#define IDC_RADIOID                     1003
#define IDC_RADIO2                      1003
#define IDC_EDIT_GRID_HEIGHT            1003
#define IDC_KEYWORDS                    1003
#define IDC_BACKWARD_RADIO              1003
#define IDC_RADIO3                      1004
#define IDC_EDIT_LEFT                   1004
#define IDC_EDIT_TOP                    1005
#define IDC_RADIO4                      1005
#define IDC_POSITION                    1005
#define IDC_GUMP_ID                     1006
#define IDC_EDIT_RIGHT                  1006
#define IDC_RADIO5                      1006
#define IDC_LINE                        1006
#define IDC_GUMP_ID2                    1007
#define IDC_EDIT_BOTTOM                 1007
#define IDC_RADIO6                      1007
#define IDC_GUMP_ID3                    1008
#define IDC_EDIT_TITLE                  1008
#define IDC_NEXT                        1008
#define IDC_RADIO7                      1008
#define IDC_BUTTON_APPLY                1009
#define IDC_RADIO8                      1009
#define IDC_MAX                         1009
#define IDC_SPIN1                       1010
#define IDC_REPLACE                     1010
#define IDC_SPIN2                       1011
#define IDC_COMBO1                      1011
#define IDC_REPLACETEXT                 1011
#define IDC_TYPE_COMBO                  1011
#define IDC_SPIN3                       1012
#define IDC_SCINCTRL                    1012
#define IDC_BUTTON2                     1013
#define IDC_SPIN6                       1013
#define IDC_SEARCHTEXT                  1013
#define IDC_BUTTON3                     1014
#define IDC_XPOS                        1014
#define IDC_SPIN7                       1014
#define IDC_MATCHCASE                   1014
#define IDC_POS                         1014
#define IDC_YPOS                        1015
#define IDC_SPIN4                       1015
#define IDC_SPIN9                       1015
#define IDC_MATCHWORDS                  1015
#define IDC_WIDTH                       1016
#define IDC_YPOS2                       1016
#define IDC_YSPIN                       1016
#define IDC_SPIN10                      1016
#define IDC_MATCHREGEX                  1016
#define IDC_HEIGHT                      1017
#define IDC_SPIN5                       1017
#define IDC_W                           1017
#define IDC_SPIN11                      1017
#define IDC_PREV                        1017
#define IDC_GUMP_ID4                    1017
#define IDC_WIDTH2                      1018
#define IDC_REPLACEALL                  1018
#define IDC_SPIN12                      1018
#define IDC_HEIGHT2                     1019
#define IDC_COMBO2                      1019
#define IDC_MATCHSELECTION              1019
#define IDC_GUMP_ID5                    1019
#define IDC_EVENT_ONCLICK               1020
#define IDC_COLOR                       1020
#define IDC_EVENT_HANDLER               1020
#define IDC_SPIN13                      1020
#define IDC_EVENT_ONCLOSE               1021
#define IDC_FONT_COMBO                  1021
#define IDC_HUE                         1021
#define IDC_EVENT_TYPE                  1021
#define IDC_GUMP_ID6                    1021
#define IDC_EVENT_ONMOUSEUP             1022
#define IDC_SPIN14                      1022
#define IDC_EVENT_ONMOUSEDOWN           1023
#define IDC_HUEID_EDIT                  1023
#define IDC_GUMP_ID7                    1023
#define IDC_EVENT_ONKEYPRESSED          1024
#define IDC_RGB_EDIT                    1024
#define IDC_SPIN15                      1024
#define IDC_COLOR_STATIC                1025
#define IDC_GROUP                       1025
#define IDC_HSPIN                       1025
#define IDC_GUMP_ID8                    1025
#define IDC_TEXT_STATIC                 1026
#define IDC_SPIN8                       1026
#define IDC_SPIN                        1026
#define IDC_SPIN16                      1026
#define IDC_PASSWORD_CHECK              1027
#define IDC_NAME                        1028
#define IDC_TYPE                        1029
#define IDC_CHECK3                      1030
#define IDC_CTRL_LIST                   1031
#define IDC_ALPHA                       1032
#define IDC_XSPIN                       1033
#define IDC_FADE_ALPHA                  1033
#define IDC_WSPIN                       1034
#define IDC_FADE_TIME                   1034
#define IDC_ALPHASPIN                   1035
#define IDC_H                           1036
#define IDC_ALPHASPIN2                  1036
#define IDC_GUMP_SPIN                   1037
#define IDC_ALPHASPIN3                  1037
#define IDC_SHAPE                       1038
#define IDC_SELECT                      1039
#define IDC_UNSELECT                    1040
#define IDC_UP                          1043
#define IDC_DOWN                        1044
#define IDC_LIST1                       1044
#define IDC_TOP                         1045
#define IDC_MIN                         1045
#define IDC_BOTTOM                      1046
#define IDC_ORDER_CHANGE                1047
#define IDC_VERTICAL                    1047
#define IDC_ARROWBTN                    1048
#define IDC_MULTILINE_CHECK             1048
#define IDC_CODE_BUTTON                 1049
#define IDC_VISIBLE_CHECK               1050
#define IDC_DISABLE_CHECK               1051
#define IDC_CUSTOM_EDIT                 1051
#define IDC_GROUP_CHECK                 1053
#define IDC_TYPE_COMBO2                 1054
#define IDC_CHECKED_CHECK               1055
#define IDC_XML_EDIT                    1056
#define IDC_CHECK1                      1057
#define IDC_IRIS_EDIT                   1057
#define IDC_INSERT                      1057
#define IDC_CHECK2                      1058
#define IDC_VISIBLE                     1275
#define IDC_HIDE                        1275
#define IDC_UNHIDE                      1276
#define IDC_LISTBOXTEXT                 1336
#define IDC_LISTBOXINFO                 1360
#define IDC_TABORDERLABEL               1361
#define IDC_TABORDERLABEL2              1362
#define IDC_TABORDERLABEL3              1363
#define IDC_TABORDERLABEL4              1364
#define IDC_TABORDERLABEL5              1365
#define IDC_TABORDERLABEL6              1366
#define IDC_TABORDERLABEL7              1367
#define IDC_TABORDERLABEL8              1368
#define IDC_TABORDERLABEL9              1369
#define IDC_TABORDERLABEL10             1370
#define IDC_TABORDERLABEL11             1371
#define IDC_TABORDERLABEL12             1372
#define IDC_LISTITEMS                   1842
#define IDC_READONLY                    1963
#define ID_OPTIONS_VIEW_LINENUMBERS     32771
#define IDC_PROPERTIES                  32772
#define ID_OPTIONS_FOREGROUND           32773
#define IDC_SETTINGS                    32774
#define IDC_PROPERTIES2                 32774
#define ID_ADD_BUTTON                   32775
#define IDC_SETTINGS2                   32775
#define ID_OPTIONS_SETFONT              32775
#define ID_ADD_EDIT                     32776
#define ID_ADD_STATIC                   32777
#define ID_ADD_BUTTON2                  32777
#define IDC_90PERC                      32778
#define ID_ADD_EDIT2                    32778
#define ID_OPTIONS_SELECTION_MARGIN     32779
#define IDC_70PERC                      32780
#define IDC_60PERC                      32781
#define ID_ADD_STATIC2                  32781
#define IDC_50PERC                      32782
#define IDC_90PERC2                     32782
#define IDC_25PERC                      32783
#define IDC_80PERS                      32783
#define IDC_100PERC                     32784
#define IDC_70PERC2                     32784
#define IDC_110PERC                     32785
#define IDC_60PERC2                     32785
#define IDC_120PERC                     32786
#define IDC_50PERC2                     32786
#define IDC_130PERC                     32787
#define IDC_25PERC2                     32787
#define IDC_140PERC                     32788
#define IDC_100PERC2                    32788
#define IDC_150PERC                     32789
#define IDC_110PERC2                    32789
#define IDC_200PERC                     32790
#define IDC_120PERC2                    32790
#define IDC_80PERC                      32791
#define IDC_130PERC2                    32791
#define IDC_SELECT_ALL                  32792
#define IDC_140PERC2                    32792
#define IDC_150PERC2                    32793
#define ID_ADD_CHECKBOX                 32794
#define IDC_200PERC2                    32794
#define ID_ADD_RADIOBUTTON              32795
#define IDC_SELECT_ALL2                 32795
#define ID_ADD_LISTBOX                  32796
#define ID_ADD_CHECKBOX2                32796
#define ID_ADD_RADIOBUTTON2             32797
#define ID_ADD_GROUPBOX                 32798
#define ID_ADD_LISTBOX2                 32798
#define ID_ZOOM_IN                      32799
#define ID_ADD_GROUPBOX2                32799
#define ID_ZOOM_OUT                     32800
#define ID_ZOOM_IN2                     32800
#define ID_ADD_COMBOBOX                 32801
#define ID_ZOOM_OUT2                    32801
#define ID_SNAP_TO_GRID                 32802
#define ID_ADD_COMBOBOX2                32802
#define ID_SNAP_TO_GRID2                32803
#define ID_SHOW_GRID                    32804
#define ID_SNAP_TO_MARGIN               32805
#define ID_MARGINS                      32806
#define ID_RESTRAIN                     32807
#define ID_LEFT_ALIGN                   32808
#define ID_RIGHT_ALIGN                  32809
#define ID_TOP_ALIGN                    32810
#define ID_BOTTOM_ALIGN                 32811
#define ID_MAKE_SAME_SIZE               32812
#define ID_UP                           32813
#define ID_DOWN                         32814
#define ID_FRONT                        32815
#define ID_BOTTOM                       32816
#define ID_EXPORT                       32817
#define ID_ADD_NONE                     32819
#define ID_BUTTON_MULTIDRAW             32821
#define ID_OPTIONS_FOLD_MARGIN          32847
#define ID_OPTIONS_ADDMARKER            32848
#define ID_OPTIONS_DELETEMARKER         32849
#define ID_OPTIONS_FIND_NEXTMARKER      32850
#define ID_OPTIONS_FIND_PREVMARKER      32851
#define ID_OPTIONS_GOTOPOS              32852
#define ID_OPTIONS_GOTOLINE             32853
#define ID_POPUP_PROPERTIES             40018
#define ID_POPUP_BRINGTOTOP             40021
#define ID_POPUP_BRINGTOBOTTOM          40022
#define ID_POPUP_GUMPIDCOPYTOCLIPBOARD  40027
#define ID_POPUP_INSERTGUMP             40028
#define ID_POPUP_COPYGUMPID             40029
#define ID_VIEW_HUEPICKER               40030
#define ID_VIEW_CONTROLLIST             40031
#define ID_VIEW_VIEWXML                 40032
#define ID_VIEW_CSLSCRIPT               40035
#define ID_VIEW_SWITCH                  40036
#define ID_ADD_CUSTOM                   40039
#define ID_BUTTON40040                  40040
#define ID_BUTTON40041                  40041
#define ID_RUN_BUTTON                   40044
#define ID_FILE_RUN                     40044
#define ID_OPTIONS_BACKGROUND           40045
#define ID_OPTIONS_BACKGROUND2          40046
#define ID_OPTIONS_WORDLIST             40047
#define ID_VIEW_SETTING                 40054
#define ID_VIEW_VIEWGUMPDESC            40058
#define ID_FILE_IMPORT                  40060
#define ID_POPUP_LOADGUMPDESC           40063
#define ID_POPUP_SAVEGUMPDESC           40064
#define ID_POPUP_EXPORTGUMPDESC         40065

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        155
#define _APS_NEXT_COMMAND_VALUE         40066
#define _APS_NEXT_CONTROL_VALUE         1058
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif
